@@ -14,7 +14,6 @@ import Control.Exception (
  )
 import qualified Control.Exception as E
 import Data.IORef
-import Data.Typeable
 import Network.Control
 import Network.HTTP.Semantics.Client
 import Network.HTTP.Semantics.IO
@@ -195,9 +194,7 @@ data Sync = Done | Cont Output
 
 ----------------------------------------------------------------
 
-data Control
-    = CFinish HTTP2Error
-    | CFrames (Maybe SettingsList) [ByteString]
+data Control = CFrames (Maybe SettingsList) [ByteString]
 
 ----------------------------------------------------------------
 
@@ -217,8 +214,7 @@ data HTTP2Error
     | StreamErrorIsReceived ErrorCode StreamId
     | StreamErrorIsSent ErrorCode StreamId ReasonPhrase
     | BadThingHappen E.SomeException
-    | GoAwayIsSent
-    deriving (Show, Typeable)
+    deriving (Show)
 
 instance E.Exception HTTP2Error
 
@@ -273,6 +269,7 @@ data Config = Config
     -- ^ This is copied into 'Aux', if exist, on server.
     , confPeerSockAddr :: SockAddr
     -- ^ This is copied into 'Aux', if exist, on server.
+    , confReadNTimeout :: Bool
     }
 
 isAsyncException :: Exception e => e -> Bool
